==> haskell-data-dword-0.3.2.1-84-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-7uF40w5qflUJ18dlpqdfin
key:                  data-dword-0.3.2.1-7uF40w5qflUJ18dlpqdfin
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  ecaad2765f816c5ba4e73fc11d4d32e0
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-7uF40w5qflUJ18dlpqdfin
depends:
    base-4.16.4.0 data-bword-0.1.0.2-IgI0nMiG7Tw33JNJL0agvV
    ghc-prim-0.8.0 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.2.1-86.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-dword
version:              0.3.2.1
visibility:           public
id:                   data-dword-0.3.2.1-KjZD9IZlXyhLAyVQLiPjpZ
key:                  data-dword-0.3.2.1-KjZD9IZlXyhLAyVQLiPjpZ
license:              BSD-3-Clause
copyright:            2011-2019 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-dword
synopsis:             Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.

category:             Data
abi:                  d7ba431ca2fea698e149280e40f5f984
exposed:              True
exposed-modules:      Data.DoubleWord Data.DoubleWord.TH
hidden-modules:       Data.DoubleWord.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-dword-0.3.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-dword-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-dword
hs-libraries:         HSdata-dword-0.3.2.1-KjZD9IZlXyhLAyVQLiPjpZ
depends:
    base-4.16.4.0 data-bword-0.1.0.2-IgI0nMiG7Tw33JNJL0agvV
    ghc-prim-0.8.0 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html:         /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
